@@ -1,14 +1,15 @@
 /*
  *  agShell
- *  $Id: agShell.c,v 4.22 2007/08/05 17:09:50 bkorb Exp $
+ *  $Id: agShell.c,v 4.28 2009/01/01 01:01:00 bkorb Exp $
  *
- *  Time-stamp:        "2007-07-04 11:14:29 bkorb"
- *  Last Committed:    $Date: 2007/08/05 17:09:50 $
+ *  Time-stamp:        "2008-12-31 13:55:28 bkorb"
+ *  Last Committed:    $Date: 2009/01/01 01:01:00 $
  *
  *  Manage a server shell process
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -235,42 +236,7 @@ chainOpen( int       stdinFd,
     if (pzShell = *ppArgs,
        (pzShell == NULL) || (*pzShell == NUL)) {
 
-        if (pzShellProgram != NULL)
-            pzShell = pzShellProgram;
-
-        else {
-            static char const sh_z[] = "sh";
-            static char const bin_sh[] = "/bin/sh";
-
-            pzShellProgram = getenv( zShellEnv );
-            if (pzShellProgram == NULL) {
-#               ifdef __sun
-                static char const xpg_sh[] = "/usr/xpg4/bin/sh";
-#               endif
-
-            no_useful_SHELL:
-#               ifdef __sun
-                if (access(xpg_sh, X_OK) == 0)
-                    pzShellProgram = xpg_sh;
-                else
-#               endif
-                    if (access(bin_sh, X_OK) == 0)
-                         pzShellProgram = bin_sh;
-                    else pzShellProgram = sh_z;
-
-            } else {
-                char const * pze = pzShellProgram + strlen(pzShellProgram);
-                if (  ((pze - pzShellProgram) > 2)
-                   && (pze[-3] == 'c')
-                   && (pze[-2] == 's')
-                   && (pze[-1] == 'h'))  {
-                    goto no_useful_SHELL;
-                }
-            }
-            putenv( aprf( "%s=%s", zShellEnv, pzShellProgram ));
-            pzShell = pzShellProgram;
-        }
-
+        pzShell = pzShellProgram;
         *ppArgs = pzShell;
     }
 
@@ -506,7 +472,7 @@ loadData( void )
      *  Trim off all trailing white space and shorten the buffer
      *  to the size actually used.
      */
-    while ((pzScan > pzText) && isspace( pzScan[-1] )) pzScan--;
+    while ((pzScan > pzText) && IS_WHITESPACE_CHAR(pzScan[-1])) pzScan--;
     textSize = (pzScan - pzText) + 1;
 
     if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL) {
