@@ -1,32 +1,29 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 4.29 2007/04/28 22:19:23 bkorb Exp $
+ *  $Id: autogen.h,v 4.34 2009/01/01 01:01:00 bkorb Exp $
  *
- *  Time-stamp:        "2007-03-25 07:44:02 bkorb"
- *  Last Committed:    $Date: 2007/04/28 22:19:23 $
+ *  Time-stamp:        "2008-12-31 13:53:26 bkorb"
+ *  Last Committed:    $Date: 2009/01/01 01:01:00 $
  *
  *  Global header file for AutoGen
- */
-
-/*
- *  AutoGen copyright 1992-2007 Bruce Korb
  *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
  *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * AutoGen is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ * AutoGen is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef AUTOGEN_BUILD
 #define AUTOGEN_BUILD 1
@@ -39,6 +36,8 @@
 #include <guile/gh.h>
 
 #include "opts.h"
+#include "expr.h"
+#include "autoopts/autoopts.h"
 #include "directive.h"
 #include "snprintfv/printf.h"
 
@@ -47,10 +46,6 @@
 #  define STR(s)  _STR(s)
 #endif
 
-#define ISNAMECHAR( c ) (isalnum(c) || ((c) == '_') || ((c) == '-'))
-
-#define STRSIZE( s )  (sizeof(s)-1)
-
 #ifdef DEFINING
 #  define VALUE( s )  = s
 #  define MODE
@@ -81,8 +76,8 @@ typedef struct {
 
 typedef unsigned char* tpChar;
 
-#include "expr.h"
-#include "autoopts/autoopts.h"
+#define STRSIZE( s )  (sizeof(s)-1)
+
 #include "cgi-fsm.h"
 #include "defParse-fsm.h"
 
@@ -256,6 +251,7 @@ struct scanContext {
 struct outSpec {
     tOutSpec*   pNext;
     char const* pzFileFmt;
+    ag_bool     deallocFmt;
     char        zSuffix[ 1 ];
 };
 
@@ -304,6 +300,9 @@ typedef struct {
     char*   entries[1];
 } tList;
 
+#define _MkStr(_s) #_s
+#define MK_STR(_s) _MkStr(_s)
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *  GLOBAL VARIABLES
@@ -330,7 +329,7 @@ MODE FILE*       pfTrace          VALUE( NULL );
 MODE char*       pzTmpStderr      VALUE( NULL );
 
 MODE tCC*        serverArgs[2]    VALUE( { NULL } );
-MODE tCC*        pzShellProgram   VALUE( NULL );
+MODE tCC*        pzShellProgram   VALUE( MK_STR(CONFIG_SHELL) );
 
 /*
  *  AutoGen definiton and template context
@@ -414,6 +413,7 @@ MKSTRING( NotStr,     "ERROR: %s is not a string\n" );
 MKSTRING( DevNull,    "/dev/null" );
 MKSTRING( ShellEnv,   "SHELL" );
 MKSTRING( Format,     "format" );
+MKSTRING( FileFormat, "%s%s\0%s.%s" );
 MKSTRING( Nil,        "" );
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
