@@ -1,9 +1,9 @@
 /*
  *  defDirect.c
- *  $Id: defDirect.c,v 4.20 2007/11/17 21:01:53 bkorb Exp $
+ *  $Id: defDirect.c,v 4.22 2008/09/28 23:23:36 bkorb Exp $
  *
- *  Time-stamp:        "2007-11-17 09:46:24 bkorb"
- *  Last Committed:    $Date: 2007/11/17 21:01:53 $
+ *  Time-stamp:        "2008-09-23 09:06:37 bkorb"
+ *  Last Committed:    $Date: 2008/09/28 23:23:36 $
  *
  *  This module processes definition file directives.
  *
@@ -15,7 +15,8 @@
  *    trail='\+\+\+ End of Directives'
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -227,7 +228,7 @@ skipToEndif( char* pzStart )
             if (pz != NULL)
                  pzRet = pz+1;
             else pzRet = pzScan + strlen( pzScan );
-            goto leave;
+            goto leave_func;
         }
 
         case DIR_IFDEF:
@@ -246,7 +247,7 @@ skipToEndif( char* pzStart )
         }  /* switch (findDirective( pzScan )) */
     }
 
- leave:
+ leave_func:
     while (pzStart < pzRet) {
         if (*(pzStart++) == '\n')
             pCurCtx->lineNo++;
@@ -352,7 +353,7 @@ skipToElseEnd( char* pzStart )
             if (pz != NULL)
                  pzRet = pz+1;
             else pzRet = pzScan + strlen( pzScan );
-            goto leave;
+            goto leave_func;
         }
 
         case DIR_IFDEF:
@@ -373,7 +374,7 @@ skipToElseEnd( char* pzStart )
         }  /* switch (findDirective( pzScan )) */
     }
 
- leave:
+ leave_func:
     while (pzStart < pzRet) {
         if (*(pzStart++) == '\n')
             pCurCtx->lineNo++;
