@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sun Nov 16 16:03:59 PST 2008
+ * Generated Wed Dec 31 19:07:29 PST 2008
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -108,6 +108,9 @@ canonicalizeName( char* pzD, char const* pzS, int srcLen );
 LOCAL tDefEntry*
 findDefEntry( char* pzName, ag_bool* pIsIndexed );
 
+LOCAL void
+print_used_defines(void);
+
 LOCAL tDefEntry**
 findEntryList( char* pzName );
 
