@@ -1,14 +1,16 @@
 
 /*
  *  columns.c
- *  $Id: columns.c,v 4.11 2007/07/04 20:51:17 bkorb Exp $
- *  Time-stamp:        "2007-07-04 11:54:49 bkorb"
+ *  $Id: columns.c,v 4.16 2008/12/20 18:35:28 bkorb Exp $
+ *  Time-stamp:        "2008-12-06 15:18:09 bkorb"
  *
- *  Columns copyright (c) 1992-2007 Bruce Korb - all rights reserved
+ *  Columns copyright (c) 1992-2008 Bruce Korb - all rights reserved
+ *  Columns copyright (c) 1992-2008 Bruce Korb - all rights reserved
  *  Columns is free software.
  *  This file is part of AutoGen.
  *
- *  AutoGen copyright (c) 1992-2007 Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 Bruce Korb - all rights reserved
  *
  *  AutoGen is free software: you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -37,17 +39,18 @@ typedef struct print_list tPrintList, *tpPrintList;
 int maxEntryWidth = 0;
 int fillColumnCt  = 0;
 
-char zLine[ 133 ];
-char zFmtLine[ 133 ];
+#define LINE_LIMIT 4096
+char zLine[ LINE_LIMIT ];
+char zFmtLine[ LINE_LIMIT ];
 
 char**  papzLines  = (char**)NULL;
 tCC*    pzLinePfx  = NULL;
 tCC*    pzFirstPfx = NULL;
 size_t  allocCt    = 0;
 size_t  usedCt     = 0;
-size_t  lineWidth  = 79;
 size_t  columnCt   = 0;
 size_t  columnSz   = 0;
+size_t  indentSize = 0;
 
 /* = = = START-STATIC-FORWARD = = = */
 /* static forward declarations maintained by :mkfwd */
@@ -63,6 +66,9 @@ writeColumns( void );
 static void
 writeRows( void );
 
+static void
+writeFill( void );
+
 static int
 compProc( const void* p1, const void* p2 );
 /* = = = END-STATIC-FORWARD = = = */
@@ -76,12 +82,9 @@ main( int    argc,
         USAGE( EXIT_FAILURE );
     }
 
-    if (HAVE_OPT( WIDTH ))
-        lineWidth = OPT_VALUE_WIDTH;
-
     if (HAVE_OPT( INDENT )) {
-        size_t indentSize = handleIndent( OPT_ARG( INDENT ));
-        lineWidth -= indentSize;
+        indentSize = handleIndent( OPT_ARG( INDENT ));
+        OPT_VALUE_WIDTH -= indentSize;
 
         if (! HAVE_OPT( FIRST_INDENT ))
             pzFirstPfx = pzLinePfx;
@@ -102,13 +105,12 @@ main( int    argc,
              *  as the indentSize
              */
             if (firstSize > indentSize) {
-                char* p = malloc( indentSize + 1 );
-                strncpy( p, pzFirstPfx, indentSize );
-                p[ indentSize ] = NUL;
-                pzFirstPfx = p;
-                fprintf( stderr, "Warning: prefix `%s' has been truncated to ",
-                         pzFirstPfx );
-                fprintf( stderr, "`%s'\n", pzFirstPfx );
+                static char const zSepLine[] =
+                    "Note: prefix `%s' has been put on a separate line\n";
+                fputs(pzFirstPfx, stdout);
+                putc('\n', stdout);
+                fprintf( stderr, zSepLine, pzFirstPfx );
+                pzFirstPfx = pzLinePfx;
 
             } else if (firstSize < indentSize) {
                 char* tmp = malloc( indentSize + 1 );
@@ -121,7 +123,7 @@ main( int    argc,
     }
 
     if (HAVE_OPT( LINE_SEPARATION ))
-        lineWidth -= strlen( OPT_ARG( LINE_SEPARATION ));
+        OPT_VALUE_WIDTH -= strlen( OPT_ARG( LINE_SEPARATION ));
 
     if (HAVE_OPT( COL_WIDTH ))
         columnSz = OPT_VALUE_COL_WIDTH;
@@ -129,8 +131,8 @@ main( int    argc,
     if (HAVE_OPT( COLUMNS ))
         columnCt = OPT_VALUE_COLUMNS;
 
-    if (lineWidth <= 16)
-        lineWidth = 16;
+    if (OPT_VALUE_WIDTH <= 16)
+        OPT_VALUE_WIDTH = 16;
 
     readLines();
 
@@ -139,6 +141,8 @@ main( int    argc,
 
     if (HAVE_OPT( BY_COLUMNS ))
          writeColumns();
+    else if (HAVE_OPT(FILL))
+        writeFill();
     else writeRows();
 
     return EXIT_SUCCESS;
@@ -149,34 +153,28 @@ static uint32_t
 handleIndent( tCC* pzIndentArg )
 {
     char* pz;
-    uint32_t colCt = strtoul( pzIndentArg, &pz, 0 );
+    unsigned int colCt = (unsigned int)strtoul(pzIndentArg, &pz, 0);
 
     /*
      *  IF the indent argument is a number
      */
-    if (*pz == '\0') {
+    if ((*pz == NUL) && (colCt > 0) && (colCt < OPT_VALUE_WIDTH)) {
         char* p;
 
-        /*
-         *  AND that number is reasonable, ...
-         */
-        if (colCt <= 0)
-            return 0;
-
         /*
          *  Allocate a string to hold the line prefix
          */
         pzLinePfx = p = malloc( (size_t)colCt + 1 );
         if (pzLinePfx == NULL) {
-            fprintf( stderr, "Cannot malloc %d bytes\n", colCt + 1 );
+            fprintf(stderr, "Cannot malloc %u bytes\n", colCt + 1);
             exit( EXIT_FAILURE );
         }
 
         /*
          *  Set it to a NUL terminated string of spaces
          */
-        memset( p, ' ', (size_t)colCt );
-        p[ colCt ] = '\0';
+        memset(p, ' ', (size_t)colCt);
+        p[colCt] = NUL;
 
     } else {
         tCC* p;
@@ -195,7 +193,7 @@ handleIndent( tCC* pzIndentArg )
              *  strings some time in the future, but not now.
              */
             switch (*p++) {
-            case '\0':
+            case NUL:
                 goto colsCounted;
 
             case '\t':
@@ -224,7 +222,7 @@ handleIndent( tCC* pzIndentArg )
 
 
 static void
-readLines( void )
+readLines(void)
 {
     int   sepLen;
 
@@ -249,23 +247,25 @@ readLines( void )
          */
         len = strlen( pzText );
         pzText += len;
-        while (isspace( pzText[-1] )) {
-            if (--pzText == zLine)
+        while (isspace(pzText[-1])) {
+            if (--pzText == zLine) {
+                if (HAVE_OPT(FILL))
+                    break;
                 goto next_line;
+            }
             len--;
         }
 
-        *pzText = '\0';
+        *pzText = NUL;
 
         /*
          *  IF the input lines are to be reformatted,
          *  THEN the length is the result of the sprintf
          *  Else, compute the length.
          */
-        if (HAVE_OPT( FORMAT )) {
+        if (HAVE_OPT(FORMAT)) {
             pzText = zFmtLine;
-            len = snprintf( zFmtLine, sizeof(zFmtLine), OPT_ARG( FORMAT ),
-                            zLine );
+            len = snprintf(zFmtLine, sizeof(zFmtLine), OPT_ARG(FORMAT), zLine);
         } else {
             pzText = zLine;
         }
@@ -292,7 +292,7 @@ readLines( void )
          *  the entries may get reordered.
          */
         if (sepLen > 0)
-            strcat( pzL, OPT_ARG( SEPARATION ));
+            strcat( pzL, OPT_ARG(SEPARATION));
 
         if (len > maxEntryWidth)
             maxEntryWidth = len;
@@ -300,15 +300,15 @@ readLines( void )
     }
 
     if (maxEntryWidth == 0) {
-        fputs( "Warning:  no input text was read\n", stderr );
+        fputs( "columns warning:  no input text was read\n", stderr );
         exit( EXIT_SUCCESS );
     }
 
     /*
      *  Set the line width to the amount of space we have to play with.
      */
-    if (lineWidth < maxEntryWidth)
-        lineWidth = maxEntryWidth;
+    if ((OPT_VALUE_WIDTH < maxEntryWidth) && (! HAVE_OPT(FILL)))
+        OPT_VALUE_WIDTH = maxEntryWidth;
 
     /*
      *  If we do not have a column size set,
@@ -320,13 +320,13 @@ readLines( void )
          *  THEN compute it.
          */
         if (columnCt == 0)
-            columnCt = lineWidth / maxEntryWidth;
+            columnCt = OPT_VALUE_WIDTH / maxEntryWidth;
 
         /*
          *  IF there are to be multiple columns, ...
          */
         if (columnCt > 1) {
-            int  spreadwidth = lineWidth - maxEntryWidth;
+            int  spreadwidth = OPT_VALUE_WIDTH - maxEntryWidth;
             int  sz = spreadwidth / (columnCt-1);
 
             /*
@@ -339,7 +339,7 @@ readLines( void )
                 columnCt = (spreadwidth / maxEntryWidth) + 1;
                 if (columnCt > 1)
                      columnSz = spreadwidth / (columnCt - 1);
-                else columnSz = lineWidth;
+                else columnSz = OPT_VALUE_WIDTH;
             }
         }
     }
@@ -360,8 +360,8 @@ readLines( void )
          *  THEN compute the number of columns.
          */
         if (  (columnCt == 0)
-           || ( ((columnSz * (columnCt-1)) + maxEntryWidth) > lineWidth ))
-            columnCt = ((lineWidth - maxEntryWidth) / columnSz) + 1;
+           || (((columnSz * (columnCt-1)) + maxEntryWidth) > OPT_VALUE_WIDTH))
+            columnCt = ((OPT_VALUE_WIDTH - maxEntryWidth) / columnSz) + 1;
     }
 
     /*
@@ -433,7 +433,7 @@ writeColumns( void )
          *  even if the user specified a count!!
          */
         colCt--;
-        rem   = lineWidth - (colCt * maxEntryWidth);
+        rem   = OPT_VALUE_WIDTH - (colCt * maxEntryWidth);
 
         if ((rem == 0) || (colCt < 2) || (columnSz > 0))
             fsz = maxEntryWidth;
@@ -495,10 +495,10 @@ writeColumns( void )
             if (HAVE_OPT( SEPARATION )) {
                 char* pz = pzE + strlen( pzE )
                          - strlen( OPT_ARG( SEPARATION ));
-                *pz = '\0';
+                *pz = NUL;
             }
             fputs( pzE, stdout );
-            fputc( '\n', stdout );
+            putc( '\n', stdout );
             break;
         }
 
@@ -511,7 +511,7 @@ writeColumns( void )
         if (HAVE_OPT( LINE_SEPARATION ))
             fputs( OPT_ARG( LINE_SEPARATION ), stdout );
 
-        fputc( '\n', stdout );
+        putc( '\n', stdout );
         free( (void*)pzE );
     }
 }
@@ -533,7 +533,7 @@ writeRows( void )
     if (HAVE_OPT( SEPARATION )) {
         char* pz = papzLines[ usedCt-1 ];
         pz += strlen( pz ) - strlen( OPT_ARG( SEPARATION ));
-        *pz = '\0';
+        *pz = NUL;
     }
 
     if (pzFirstPfx != NULL) {
@@ -558,7 +558,7 @@ writeRows( void )
              */
             if (--left <= 0) {
                 fputs( pzL, stdout );
-                fputc( '\n', stdout );
+                putc( '\n', stdout );
                 free( (void*)pzL );
                 break;
             }
@@ -582,7 +582,7 @@ writeRows( void )
                 if (HAVE_OPT( LINE_SEPARATION ))
                     fputs( OPT_ARG( LINE_SEPARATION ), stdout );
 
-                fputc( '\n', stdout );
+                putc( '\n', stdout );
 
                 /*
                  *  Start the next line with any required indentation
@@ -594,10 +594,95 @@ writeRows( void )
             }
 
             free( (void*)pzL );
-        } while (left > 0);
+        }
     }
 }
 
+static int
+emitWord(char const * word, size_t len, int col)
+{
+    static int ended_with_period = 0;
+
+    if (col > 0) {
+        if (len >= (OPT_VALUE_WIDTH - col)) {
+            putc('\n', stdout);
+            if (pzLinePfx != NULL)
+                fputs(pzLinePfx, stdout);
+            col = 0;
+
+        } else {
+            if (ended_with_period) {
+                putc(' ', stdout);
+                col++;
+            }
+            putc(' ', stdout);
+            col++;
+        }
+    }
+
+    fwrite(word, len, 1, stdout);
+    col += len;
+    ended_with_period = (word[len - 1] == '.');
+
+    return col;
+}
+
+
+static void
+writeFill( void )
+{
+    char**  ppzLL = papzLines;
+    size_t  left  = usedCt;
+    int     colNo = 0;
+
+    if (pzFirstPfx != NULL)
+        fputs(pzFirstPfx, stdout);
+
+    /*
+     *  FOR every entry we are to emit, ...
+     */
+    while (left-- > 0) {
+        char* pzL = *ppzLL;
+
+        while (isspace(*pzL))  pzL++;
+
+        /*
+         *  Blank lines are magical and trigger a blank line in output.
+         */
+        if (*pzL == NUL) {
+            if (colNo > 0) /* guard against multiple blank lines */
+                putc('\n', stdout);
+            putc('\n', stdout);
+            colNo = -2;
+            free(*(ppzLL++));
+            continue;
+        }
+
+        /*
+         *  We are going to emit some output.  Make sure we're indented.
+         */
+        if (colNo < 0) {
+            if (pzLinePfx != NULL)
+                fputs(pzLinePfx, stdout);
+            colNo = 0;
+        }
+
+        do {
+            size_t tknlen;
+
+            for (tknlen = 0; pzL[tknlen] != NUL; tknlen++)
+                if (isspace(pzL[tknlen]))
+                    break;
+            colNo = emitWord(pzL, tknlen, colNo);
+            pzL += tknlen;
+            while (isspace(*pzL))  pzL++;
+        } while (*pzL != NUL);
+
+        free(*(ppzLL++));
+    }
+    putc( '\n', stdout );
+}
+
 
 /*
  *  Line comparison procedure
