@@ -1,18 +1,35 @@
 /*
- *  $Id: gdinit.c,v 4.8 2007/04/28 22:19:23 bkorb Exp $
+ *  $Id: gdinit.c,v 4.12 2008/12/29 06:14:25 bkorb Exp $
  *
  *    getdefs copyright 1999-2007 Bruce Korb
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
- *  Time-stamp:        "2007-04-28 11:31:58 bkorb"
- *  Last Modified:     $Date: 2007/04/28 22:19:23 $
+ *  Time-stamp:        "2008-12-28 10:35:38 bkorb"
+ *  Last Modified:     $Date: 2008/12/29 06:14:25 $
  *            by: bkorb
+ *
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2008 Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 Bruce Korb - all rights reserved
+ *
+ *  AutoGen is free software: you can redistribute it and/or modify it
+ *  under the terms of the GNU General Public License as published by the
+ *  Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  AutoGen is distributed in the hope that it will be useful, but
+ *  WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ *  See the GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 tSCC zNoList[] = "ERROR:  block attr must have name list:\n\t%s\n";
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static char*
 compressOptionText( char* pzS, char* pzE );
 
@@ -258,16 +275,24 @@ processEmbeddedOptions( char* pzText )
 LOCAL void
 validateOptions( void )
 {
+    static char const default_pat[] =
+        "/\\*=(\\*|"
+        "([a-z][a-z0-9_]*(\\[[0-9]+\\]){0,1}|\\*)[ \t]+[a-z])";
+    static char const pat_wrapper[] = "/\\*=(%s)";
+    ag_bool free_pat = AG_FALSE;
+
     /*
      *  Our default pattern is to accept all names following
      *  the '/' '*' '=' character sequence.  We ignore case.
      */
-    if ((! HAVE_OPT( DEFS_TO_GET )) || (*OPT_ARG( DEFS_TO_GET ) == NUL)) {
-        pzDefPat = "/\\*=(\\*|"
-                   "([a-z][a-z0-9_]*(\\[[0-9]+\\]){0,1}|\\*)[ \t]+[a-z])";
+    if ((! HAVE_OPT(DEFS_TO_GET)) || (*OPT_ARG(DEFS_TO_GET) == NUL)) {
+        pzDefPat = default_pat;
+
+    } else if (strncmp(OPT_ARG(DEFS_TO_GET), default_pat, 4) == 0) {
+        pzDefPat = OPT_ARG(DEFS_TO_GET);
 
     } else {
-        tCC*   pz  = OPT_ARG( DEFS_TO_GET );
+        tCC*   pz  = OPT_ARG(DEFS_TO_GET);
         size_t len = strlen( pz ) + 16;
         char*  bf  = malloc( len );
 
@@ -280,8 +305,9 @@ validateOptions( void )
          *  IF a pattern has been supplied, enclose it with
          *  the '/' '*' '=' part of the pattern.
          */
-        snprintf( bf, len, "/\\*=(%s)", pz );
+        snprintf( bf, len, pat_wrapper, pz );
         pzDefPat = bf;
+        free_pat = AG_TRUE;
     }
 
     /*
@@ -300,6 +326,10 @@ validateOptions( void )
             exit( EXIT_FAILURE );
         }
 
+        if (free_pat)
+            free((void *)pzDefPat);
+        pzDefPat = NULL;
+
         rerr = regcomp( &attrib_re, zAttribRe, REG_EXTENDED | REG_ICASE );
         if (rerr != 0) {
             regerror( rerr, &attrib_re, zRER, sizeof( zRER ));
@@ -340,6 +370,9 @@ validateOptions( void )
         struct stat stb;
 
         if ((ct == 1) && (strcmp( *ppz, "-" ) == 0)) {
+            /*
+             *  Read the list of input files from stdin.
+             */
             loadStdin();
             ct  = STACKCT_OPT(  INPUT );
             ppz = STACKLST_OPT( INPUT );
